@@ -13,17 +13,20 @@ void init_localematcher(py::module &m) {
 #if (U_ICU_VERSION_MAJOR_NUM >= 65)
   py::enum_<ULocMatchDemotion>(m, "ULocMatchDemotion", py::arithmetic())
       .value("ULOCMATCH_DEMOTION_NONE", ULOCMATCH_DEMOTION_NONE)
-      .value("ULOCMATCH_DEMOTION_REGION", ULOCMATCH_DEMOTION_REGION);
+      .value("ULOCMATCH_DEMOTION_REGION", ULOCMATCH_DEMOTION_REGION)
+      .export_values();
 
 #if (U_ICU_VERSION_MAJOR_NUM >= 67)
   py::enum_<ULocMatchDirection>(m, "ULocMatchDirection", py::arithmetic())
       .value("ULOCMATCH_DIRECTION_WITH_ONE_WAY", ULOCMATCH_DIRECTION_WITH_ONE_WAY)
-      .value("ULOCMATCH_DIRECTION_ONLY_TWO_WAY", ULOCMATCH_DIRECTION_ONLY_TWO_WAY);
+      .value("ULOCMATCH_DIRECTION_ONLY_TWO_WAY", ULOCMATCH_DIRECTION_ONLY_TWO_WAY)
+      .export_values();
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 67)
 
   py::enum_<ULocMatchFavorSubtag>(m, "ULocMatchFavorSubtag", py::arithmetic())
       .value("ULOCMATCH_FAVOR_LANGUAGE", ULOCMATCH_FAVOR_LANGUAGE)
-      .value("ULOCMATCH_FAVOR_SCRIPT", ULOCMATCH_FAVOR_SCRIPT);
+      .value("ULOCMATCH_FAVOR_SCRIPT", ULOCMATCH_FAVOR_SCRIPT)
+      .export_values();
 
   // icu::LocaleMatcher
   py::class_<LocaleMatcher, UMemory> lm(m, "LocaleMatcher");
@@ -41,7 +44,7 @@ void init_localematcher(py::module &m) {
           UErrorCode error_code = U_ZERO_ERROR;
           auto result = self.getBestMatch(desired_locale, error_code);
           if (U_FAILURE(error_code)) {
-            throw ICUException(error_code);
+            throw ICUError(error_code);
           }
           return result;
         },
@@ -53,7 +56,7 @@ void init_localematcher(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = self.getBestMatch(desired_locale, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -66,7 +69,7 @@ void init_localematcher(py::module &m) {
             Locale::RangeIterator<const Locale *> iter(first, first + desired_locales.size());
             auto result = self.getBestMatch(iter, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -77,7 +80,7 @@ void init_localematcher(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         auto result = self.getBestMatchForListString(desired_locale_list, error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return result;
       },
@@ -88,7 +91,7 @@ void init_localematcher(py::module &m) {
           UErrorCode error_code = U_ZERO_ERROR;
           auto result = self.getBestMatchResult(desired_locale, error_code);
           if (U_FAILURE(error_code)) {
-            throw ICUException(error_code);
+            throw ICUError(error_code);
           }
           return result;
         },
@@ -101,7 +104,7 @@ void init_localematcher(py::module &m) {
             Locale::RangeIterator<const Locale *> iter(first, first + desired_locales.size());
             auto result = self.getBestMatchResult(iter, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -113,7 +116,7 @@ void init_localematcher(py::module &m) {
           UErrorCode error_code = U_ZERO_ERROR;
           auto result = self.isMatch(desired, supported, error_code);
           if (U_FAILURE(error_code)) {
-            throw ICUException(error_code);
+            throw ICUError(error_code);
           }
           return result;
         },
@@ -125,7 +128,7 @@ void init_localematcher(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = self.isMatch(desired, supported, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -137,7 +140,7 @@ void init_localematcher(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = self.isMatch(desired, supported, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -150,7 +153,7 @@ void init_localematcher(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = self.isMatch(desired, supported, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -169,7 +172,7 @@ void init_localematcher(py::module &m) {
     UErrorCode error_code = U_ZERO_ERROR;
     auto result = self.build(error_code);
     if (U_FAILURE(error_code)) {
-      throw ICUException(error_code);
+      throw ICUError(error_code);
     }
     return result;
   });
@@ -230,7 +233,7 @@ void init_localematcher(py::module &m) {
     UErrorCode error_code = U_ZERO_ERROR;
     auto result = self.makeResolvedLocale(error_code);
     if (U_FAILURE(error_code)) {
-      throw ICUException(error_code);
+      throw ICUError(error_code);
     }
     return result;
   });
