@@ -1,7 +1,9 @@
 #include "main.hpp"
+#include <unicode/decimfmt.h>
 #include <unicode/errorcode.h>
 #include <unicode/fmtable.h>
 #include <unicode/locid.h>
+#include <unicode/plurrule.h>
 
 #ifndef MODULE_NAME
 #define MODULE_NAME icu
@@ -12,9 +14,12 @@ using namespace icu;
 void init_appendable(py::module &m);
 void init_char16ptr(py::module &m);
 void init_coleitr(py::module &m);
+void init_compactdecimalformat(py::module &m);
+void init_currpinf(py::module &m);
 void init_currunit(py::module &m);
 void init_datefmt(py::module &m);
 void init_dcfmtsym(py::module &m);
+void init_decimfmt(py::module &m, py::class_<DecimalFormat, NumberFormat> &df);
 void init_dtfmtsym(py::module &m);
 void init_dtintrv(py::module &m);
 void init_dtitvfmt(py::module &m);
@@ -35,17 +40,24 @@ void init_locid(py::module &m, py::class_<Locale, UObject> &loc);
 void init_measfmt(py::module &m);
 void init_measunit(py::module &m);
 void init_measure(py::module &m);
+void init_messagepattern(py::module &m);
+void init_msgfmt(py::module &m);
 void init_normalizer2(py::module &m);
 void init_nounit(py::module &m);
 void init_numberformatter(py::module &m, py::module &m2);
 void init_numberrangeformatter(py::module &m, py::module &m2);
+void init_numfmt(py::module &m, py::class_<NumberFormat, Format> &nf);
 void init_numsys(py::module &m);
 void init_parseerr(py::module &m);
 void init_parsepos(py::module &m);
+void init_plurfmt(py::module &m);
+void init_plurrule(py::module &m, py::class_<PluralRules, UObject> &pr);
 void init_rbbi(py::module &m);
+void init_rbnf(py::module &m);
 void init_regex(py::module &m);
 void init_resbund(py::module &m);
 void init_schriter(py::module &m);
+void init_selfmt(py::module &m);
 void init_smpdtfmt(py::module &m);
 void init_sortkey(py::module &m);
 void init_strenum(py::module &m);
@@ -82,6 +94,7 @@ void init_unorm2(py::module &m);
 void init_unum(py::module &m);
 void init_unumberformatter(py::module &m);
 void init_unumberrangeformatter(py::module &m);
+void init_upluralrules(py::module &m);
 void init_uregex(py::module &m);
 void init_ures(py::module &m);
 void init_uscript(py::module &m);
@@ -94,7 +107,7 @@ void init_utypes(py::module &m);
 void init_uversion(py::module &m);
 void init_voidptr(py::module &m);
 
-ICUException::ICUException(UErrorCode error_code, const char *message) {
+ICUError::ICUError(UErrorCode error_code, const char *message) {
   error_code_ = error_code;
   what_.append(u_errorName(error_code));
   if (message != nullptr && *message != 0) {
@@ -105,13 +118,13 @@ ICUException::ICUException(UErrorCode error_code, const char *message) {
 }
 
 PYBIND11_MODULE(MODULE_NAME, m) {
-  static py::exception<ICUException> ex(m, "ICUException");
+  static py::exception<ICUError> ex(m, "ICUError");
   py::register_exception_translator([](std::exception_ptr p) {
     try {
       if (p) {
         std::rethrow_exception(p);
       }
-    } catch (const ICUException &e) {
+    } catch (const ICUError &e) {
       ErrorCode error_code;
       error_code.set(e.get_error_code());
       auto message = e.get_message();
@@ -141,6 +154,8 @@ PYBIND11_MODULE(MODULE_NAME, m) {
 
   py::class_<Formattable, UObject> fmt(m, "Formattable");
 
+  py::class_<PluralRules, UObject> pr(m, "PluralRules");
+
   py::bind_vector<_UnicodeStringVector>(m, "UnicodeStringVector", py::module_local(false))
       .def(py::init<size_t>(), py::arg("n"));
 
@@ -166,25 +181,44 @@ PYBIND11_MODULE(MODULE_NAME, m) {
   init_nounit(m);   // icu::NoUnit
   init_measure(m);  // icu::Measure, icu::CurrencyAmount, icu::TimeUnitAmount
 
+  init_currpinf(m);     // icu::CurrencyPluralInfo
   init_dtintrv(m);      // icu::DateInterval
   init_dtitvinf(m);     // icu::DateIntervalInfo
   init_fieldpos(m);     // icu::FieldPosition
   init_fpositer(m);     // icu::FieldPositionIterator
   init_fmtable(m, fmt); // icu::Formattable
-  init_format(m);       // icu::Format
-  init_datefmt(m);      // icu::DateFormat
-  init_dtfmtsym(m);     // icu::DateFormatSymbols
-  init_dtitvfmt(m);     // icu::DateIntervalFormat
-  init_tznames(m);      // icu::TimeZoneNames
-  init_tzfmt(m);        // icu::TimeZoneFormat
-  init_smpdtfmt(m);     // icu::SimpleDateFormat
+  init_numsys(m);       // icu::NumberingSystem
+  init_dcfmtsym(m);     // icu::DecimalFormatSymbols
+
+  init_format(m); // icu::Format
+
+  py::class_<NumberFormat, Format> numfmt(m, "NumberFormat");
+
+  py::class_<DecimalFormat, NumberFormat> decfmt(m, "DecimalFormat");
+
+  init_numfmt(m, numfmt); // icu::NumberFormat
+  init_rbnf(m);           // icu::RuleBasedNumberFormat
+
+  init_datefmt(m);  // icu::DateFormat
+  init_dtfmtsym(m); // icu::DateFormatSymbols
+  init_dtitvfmt(m); // icu::DateIntervalFormat
+  init_tznames(m);  // icu::TimeZoneNames
+  init_tzfmt(m);    // icu::TimeZoneFormat
+  init_smpdtfmt(m); // icu::SimpleDateFormat
 
   init_measfmt(m); // icu::MeasureFormat
 
-  init_numsys(m);                       // icu::NumberingSystem
-  init_dcfmtsym(m);                     // icu::DecimalFormatSymbols
+  init_messagepattern(m); // icu::MessagePattern
+  init_msgfmt(m);         // icu::MessageFormat
+
+  init_selfmt(m); // icu::SelectFormat
+
   init_numberformatter(m, number);      // icu::number::NumberFormatter
   init_numberrangeformatter(m, number); // icu::number::NumberRangeFormatter
+  init_plurrule(m, pr);                 // icu::PluralRules
+  init_decimfmt(m, decfmt);             // icu::DecimalFormat
+  init_compactdecimalformat(m);         // icu::CompactDecimalFormat
+  init_plurfmt(m);                      // icu::PluralFormat
 
   init_schriter(m); // icu::StringCharacterIterator
   init_coleitr(m);  // icu::CollationElementIterator
@@ -229,6 +263,7 @@ PYBIND11_MODULE(MODULE_NAME, m) {
   init_unum(m);
   init_unumberformatter(m);
   init_unumberrangeformatter(m);
+  init_upluralrules(m);
   init_uregex(m);
   init_ures(m);
   init_uscript(m);
@@ -247,5 +282,7 @@ PYBIND11_MODULE(MODULE_NAME, m) {
   m.attr("INT16_MIN") = INT16_MIN;
   m.attr("INT32_MAX") = INT32_MAX;
   m.attr("INT32_MIN") = INT32_MIN;
+  m.attr("INT64_MAX") = INT64_MAX;
+  m.attr("INT64_MIN") = INT64_MIN;
   m.attr("U_SENTINEL") = U_SENTINEL;
 }
