@@ -14,7 +14,7 @@ void init_measure(py::module &m) {
              UErrorCode error_code = U_ZERO_ERROR;
              auto result = std::make_unique<Measure>(number, adopted_unit.clone(), error_code);
              if (U_FAILURE(error_code)) {
-               throw ICUException(error_code);
+               throw ICUError(error_code);
              }
              return result;
            }),
@@ -34,7 +34,7 @@ void init_measure(py::module &m) {
            UErrorCode error_code = U_ZERO_ERROR;
            auto result = std::make_unique<CurrencyAmount>(amount, iso_code, error_code);
            if (U_FAILURE(error_code)) {
-             throw ICUException(error_code);
+             throw ICUError(error_code);
            }
            return result;
          }),
@@ -43,7 +43,7 @@ void init_measure(py::module &m) {
              UErrorCode error_code = U_ZERO_ERROR;
              auto result = std::make_unique<CurrencyAmount>(amount, iso_code, error_code);
              if (U_FAILURE(error_code)) {
-               throw ICUException(error_code);
+               throw ICUError(error_code);
              }
              return result;
            }),
@@ -62,7 +62,7 @@ void init_measure(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = std::make_unique<TimeUnitAmount>(number, time_unit_field, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           }),
@@ -71,7 +71,7 @@ void init_measure(py::module &m) {
              UErrorCode error_code = U_ZERO_ERROR;
              auto result = std::make_unique<TimeUnitAmount>(amount, time_unit_field, error_code);
              if (U_FAILURE(error_code)) {
-               throw ICUException(error_code);
+               throw ICUError(error_code);
              }
              return result;
            }),
