@@ -45,7 +45,7 @@ void init_rbbi(py::module &m) {
           UErrorCode error_code = U_ZERO_ERROR;
           auto it = BreakIterator::createCharacterInstance(where, error_code);
           if (U_FAILURE(error_code)) {
-            throw ICUException(error_code);
+            throw ICUError(error_code);
           }
           return it;
         },
@@ -57,7 +57,7 @@ void init_rbbi(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto it = BreakIterator::createCharacterInstance(where, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return it;
           },
@@ -68,7 +68,7 @@ void init_rbbi(py::module &m) {
           UErrorCode error_code = U_ZERO_ERROR;
           auto it = BreakIterator::createLineInstance(where, error_code);
           if (U_FAILURE(error_code)) {
-            throw ICUException(error_code);
+            throw ICUError(error_code);
           }
           return it;
         },
@@ -80,7 +80,7 @@ void init_rbbi(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto it = BreakIterator::createLineInstance(where, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return it;
           },
@@ -91,7 +91,7 @@ void init_rbbi(py::module &m) {
           UErrorCode error_code = U_ZERO_ERROR;
           auto it = BreakIterator::createSentenceInstance(where, error_code);
           if (U_FAILURE(error_code)) {
-            throw ICUException(error_code);
+            throw ICUError(error_code);
           }
           return it;
         },
@@ -103,7 +103,7 @@ void init_rbbi(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto it = BreakIterator::createSentenceInstance(where, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return it;
           },
@@ -115,7 +115,7 @@ void init_rbbi(py::module &m) {
           UErrorCode error_code = U_ZERO_ERROR;
           auto it = BreakIterator::createTitleInstance(where, error_code);
           if (U_FAILURE(error_code)) {
-            throw ICUException(error_code);
+            throw ICUError(error_code);
           }
           return it;
         },
@@ -127,7 +127,7 @@ void init_rbbi(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto it = BreakIterator::createTitleInstance(where, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return it;
           },
@@ -139,7 +139,7 @@ void init_rbbi(py::module &m) {
           UErrorCode error_code = U_ZERO_ERROR;
           auto it = BreakIterator::createWordInstance(where, error_code);
           if (U_FAILURE(error_code)) {
-            throw ICUException(error_code);
+            throw ICUError(error_code);
           }
           return it;
         },
@@ -151,12 +151,23 @@ void init_rbbi(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto it = BreakIterator::createWordInstance(where, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return it;
           },
           py::arg("where"));
-  bi.def_static("get_available_locales", py::overload_cast<>(&BreakIterator::getAvailableLocales));
+  bi.def_static(
+      "get_available_locales",
+      []() {
+        int32_t count;
+        auto p = BreakIterator::getAvailableLocales(count);
+        std::vector<const Locale *> result(count);
+        for (int32_t i = 0; i < count; ++i) {
+          result[i] = p + i;
+        }
+        return result;
+      },
+      py::return_value_policy::reference);
   bi.def_static("get_display_name",
                 py::overload_cast<const Locale &, const Locale &, UnicodeString &>(&BreakIterator::getDisplayName),
                 py::arg("object_locale"), py::arg("display_locale"), py::arg("name"))
@@ -198,7 +209,7 @@ void init_rbbi(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         auto result = self.getLocale(type, error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return result;
       },
@@ -211,7 +222,7 @@ void init_rbbi(py::module &m) {
     error_code = U_ZERO_ERROR;
     self.getRuleStatusVec(result.data(), (int32_t)result.size(), error_code);
     if (U_FAILURE(error_code)) {
-      throw ICUException(error_code);
+      throw ICUError(error_code);
     }
     return result;
   });
@@ -231,7 +242,7 @@ void init_rbbi(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = std::make_unique<RuleBasedBreakIterator>(rules, parse_error, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           }),
@@ -242,7 +253,7 @@ void init_rbbi(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = std::make_unique<RuleBasedBreakIterator>(rules, parse_error, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           }),
@@ -253,7 +264,7 @@ void init_rbbi(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = std::make_unique<RuleBasedBreakIterator>(compiled_rules.data(), rule_length, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           }),
@@ -282,7 +293,7 @@ void init_rbbi(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         auto p = self.getUText(fill_in.value_or(nullptr), error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return std::make_unique<_UTextPtr>(p);
       },
@@ -302,7 +313,7 @@ void init_rbbi(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             self.setText(text, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
           },
           py::arg("text"));
