@@ -19,7 +19,7 @@ void init_tzfmt(py::module &m) {
       .value("UTZFMT_PAT_POSITIVE_H", UTZFMT_PAT_POSITIVE_H)
       .value("UTZFMT_PAT_NEGATIVE_H", UTZFMT_PAT_NEGATIVE_H)
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 51)
-      ;
+      .export_values();
 
   py::enum_<UTimeZoneFormatParseOption>(m, "UTimeZoneFormatParseOption", py::arithmetic())
       .value("UTZFMT_PARSE_OPTION_NONE", UTZFMT_PARSE_OPTION_NONE)
@@ -27,7 +27,7 @@ void init_tzfmt(py::module &m) {
 #if (U_ICU_VERSION_MAJOR_NUM >= 54)
       .value("UTZFMT_PARSE_OPTION_TZ_DATABASE_ABBREVIATIONS", UTZFMT_PARSE_OPTION_TZ_DATABASE_ABBREVIATIONS)
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 54)
-      ;
+      .export_values();
 
   py::enum_<UTimeZoneFormatStyle>(m, "UTimeZoneFormatStyle", py::arithmetic())
       .value("UTZFMT_STYLE_GENERIC_LOCATION", UTZFMT_STYLE_GENERIC_LOCATION)
@@ -52,12 +52,13 @@ void init_tzfmt(py::module &m) {
       .value("UTZFMT_STYLE_ZONE_ID_SHORT", UTZFMT_STYLE_ZONE_ID_SHORT)
       .value("UTZFMT_STYLE_EXEMPLAR_LOCATION", UTZFMT_STYLE_EXEMPLAR_LOCATION)
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 51)
-      ;
+      .export_values();
 
   py::enum_<UTimeZoneFormatTimeType>(m, "UTimeZoneFormatTimeType", py::arithmetic())
       .value("UTZFMT_TIME_TYPE_UNKNOWN", UTZFMT_TIME_TYPE_UNKNOWN)
       .value("UTZFMT_TIME_TYPE_STANDARD", UTZFMT_TIME_TYPE_STANDARD)
-      .value("UTZFMT_TIME_TYPE_DAYLIGHT", UTZFMT_TIME_TYPE_DAYLIGHT);
+      .value("UTZFMT_TIME_TYPE_DAYLIGHT", UTZFMT_TIME_TYPE_DAYLIGHT)
+      .export_values();
 
   // icu::TimeZoneFormat
   py::class_<TimeZoneFormat, Format> tzf(m, "TimeZoneFormat");
@@ -73,7 +74,7 @@ void init_tzfmt(py::module &m) {
            UErrorCode error_code = U_ZERO_ERROR;
            auto result = TimeZoneFormat::createInstance(locale, error_code);
            if (U_FAILURE(error_code)) {
-             throw ICUException(error_code);
+             throw ICUError(error_code);
            }
            return result;
          },
@@ -85,7 +86,7 @@ void init_tzfmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = TimeZoneFormat::createInstance(locale, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -98,7 +99,7 @@ void init_tzfmt(py::module &m) {
            UErrorCode error_code = U_ZERO_ERROR;
            auto &result = self.format(obj, append_to, pos, error_code);
            if (U_FAILURE(error_code)) {
-             throw ICUException(error_code);
+             throw ICUError(error_code);
            }
            return result;
          },
@@ -111,7 +112,7 @@ void init_tzfmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto &result = self.format(obj, append_to, pos_iter, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -123,7 +124,7 @@ void init_tzfmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto &result = self.format(obj, append_to, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -143,7 +144,7 @@ void init_tzfmt(py::module &m) {
         auto &string =
             self.formatOffsetISO8601Basic(offset, use_utc_indicator, is_short, ignore_seconds, result, error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return string;
       },
@@ -157,7 +158,7 @@ void init_tzfmt(py::module &m) {
         auto &string =
             self.formatOffsetISO8601Extended(offset, use_utc_indicator, is_short, ignore_seconds, result, error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return string;
       },
@@ -170,7 +171,7 @@ void init_tzfmt(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         auto &string = self.formatOffsetLocalizedGMT(offset, result, error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return string;
       },
@@ -182,7 +183,7 @@ void init_tzfmt(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         auto &string = self.formatOffsetShortLocalizedGMT(offset, result, error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return string;
       },
@@ -262,7 +263,7 @@ void init_tzfmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             self.parseObject(source, result, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
           },
           py::arg("source"), py::arg("result"))
@@ -273,7 +274,7 @@ void init_tzfmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             self.parseObject(source, result, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
           },
           py::arg("source"), py::arg("result"));
@@ -316,7 +317,7 @@ void init_tzfmt(py::module &m) {
            UErrorCode error_code = U_ZERO_ERROR;
            self.setGMTOffsetDigits(digits, error_code);
            if (U_FAILURE(error_code)) {
-             throw ICUException(error_code);
+             throw ICUError(error_code);
            }
          },
          py::arg("digits"))
@@ -327,7 +328,7 @@ void init_tzfmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             self.setGMTOffsetDigits(digits, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
           },
           py::arg("digits"));
@@ -337,7 +338,7 @@ void init_tzfmt(py::module &m) {
            UErrorCode error_code = U_ZERO_ERROR;
            self.setGMTOffsetPattern(type, pattern, error_code);
            if (U_FAILURE(error_code)) {
-             throw ICUException(error_code);
+             throw ICUError(error_code);
            }
          },
          py::arg("type_"), py::arg("pattern"))
@@ -348,7 +349,7 @@ void init_tzfmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             self.setGMTOffsetPattern(type, pattern, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
           },
           py::arg("type_"), py::arg("pattern"));
@@ -358,7 +359,7 @@ void init_tzfmt(py::module &m) {
            UErrorCode error_code = U_ZERO_ERROR;
            self.setGMTPattern(pattern, error_code);
            if (U_FAILURE(error_code)) {
-             throw ICUException(error_code);
+             throw ICUError(error_code);
            }
          },
          py::arg("pattern"))
@@ -369,7 +370,7 @@ void init_tzfmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             self.setGMTPattern(pattern, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
           },
           py::arg("pattern"));
@@ -379,7 +380,7 @@ void init_tzfmt(py::module &m) {
            UErrorCode error_code = U_ZERO_ERROR;
            self.setGMTZeroFormat(gmt_zero_format, error_code);
            if (U_FAILURE(error_code)) {
-             throw ICUException(error_code);
+             throw ICUError(error_code);
            }
          },
          py::arg("gmt_zero_format"))
@@ -390,7 +391,7 @@ void init_tzfmt(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             self.setGMTZeroFormat(gmt_zero_format, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
           },
           py::arg("gmt_zero_format"));
