@@ -35,7 +35,8 @@ void init_ubidi(py::module &m) {
       .value("UBIDI_LTR", UBIDI_LTR)
       .value("UBIDI_RTL", UBIDI_RTL)
       .value("UBIDI_MIXED", UBIDI_MIXED)
-      .value("UBIDI_NEUTRAL", UBIDI_NEUTRAL);
+      .value("UBIDI_NEUTRAL", UBIDI_NEUTRAL)
+      .export_values();
 
   py::enum_<UBiDiReorderingMode>(m, "UBiDiReorderingMode", py::arithmetic())
       .value("UBIDI_REORDER_DEFAULT", UBIDI_REORDER_DEFAULT)
@@ -44,13 +45,15 @@ void init_ubidi(py::module &m) {
       .value("UBIDI_REORDER_RUNS_ONLY", UBIDI_REORDER_RUNS_ONLY)
       .value("UBIDI_REORDER_INVERSE_NUMBERS_AS_L", UBIDI_REORDER_INVERSE_NUMBERS_AS_L)
       .value("UBIDI_REORDER_INVERSE_LIKE_DIRECT", UBIDI_REORDER_INVERSE_LIKE_DIRECT)
-      .value("UBIDI_REORDER_INVERSE_FOR_NUMBERS_SPECIAL", UBIDI_REORDER_INVERSE_FOR_NUMBERS_SPECIAL);
+      .value("UBIDI_REORDER_INVERSE_FOR_NUMBERS_SPECIAL", UBIDI_REORDER_INVERSE_FOR_NUMBERS_SPECIAL)
+      .export_values();
 
   py::enum_<UBiDiReorderingOption>(m, "UBiDiReorderingOption", py::arithmetic())
       .value("UBIDI_OPTION_DEFAULT", UBIDI_OPTION_DEFAULT)
       .value("UBIDI_OPTION_INSERT_MARKS", UBIDI_OPTION_INSERT_MARKS)
       .value("UBIDI_OPTION_REMOVE_CONTROLS", UBIDI_OPTION_REMOVE_CONTROLS)
-      .value("UBIDI_OPTION_STREAMING", UBIDI_OPTION_STREAMING);
+      .value("UBIDI_OPTION_STREAMING", UBIDI_OPTION_STREAMING)
+      .export_values();
 
   py::class_<_UBiDiClassCallbackPtr>(m, "UBiDiClassCallbackPtr")
       .def(py::init<std::nullptr_t>(), py::arg("fn"))
@@ -68,7 +71,7 @@ void init_ubidi(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         auto result = ubidi_countRuns(bidi, &error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return result;
       },
@@ -106,7 +109,7 @@ void init_ubidi(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         auto p = ubidi_getLevels(bidi, &error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         const auto length = ubidi_getProcessedLength(bidi);
         std::vector<UBiDiLevel> result(p, p + length);
@@ -119,7 +122,7 @@ void init_ubidi(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         auto result = ubidi_getLogicalIndex(bidi, visual_index, &error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return result;
       },
@@ -134,7 +137,7 @@ void init_ubidi(py::module &m) {
         std::vector<int32_t> result(length);
         ubidi_getLogicalMap(bidi, result.data(), &error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return result;
       },
@@ -157,7 +160,7 @@ void init_ubidi(py::module &m) {
         UBiDiLevel para_level;
         auto result = ubidi_getParagraph(bidi, char_index, &para_start, &para_limit, &para_level, &error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return py::make_tuple(result, para_start, para_limit, para_level);
       },
@@ -171,7 +174,7 @@ void init_ubidi(py::module &m) {
         UBiDiLevel para_level;
         ubidi_getParagraphByIndex(bidi, para_index, &para_start, &para_limit, &para_level, &error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return py::make_tuple(para_start, para_limit, para_level);
       },
@@ -196,7 +199,7 @@ void init_ubidi(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         auto result = ubidi_getVisualIndex(bidi, logical_index, &error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return result;
       },
@@ -211,7 +214,7 @@ void init_ubidi(py::module &m) {
         std::vector<int32_t> result(length);
         ubidi_getVisualMap(bidi, result.data(), &error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return result;
       },
@@ -248,7 +251,7 @@ void init_ubidi(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         auto bidi = ubidi_openSized(max_length, max_run_count, &error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return std::make_unique<_UBiDiPtr>(bidi);
       },
@@ -293,7 +296,7 @@ void init_ubidi(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         ubidi_setClassCallback(bidi, fp, cp, &old_fn, &old_context, &error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         if (old_fn == new_fn.callback) {
           // Old Python callback function and old callback data
@@ -328,7 +331,7 @@ void init_ubidi(py::module &m) {
         }
         ubidi_setContext(bidi, prologue_ptr.get(), pro_length, epilogue_ptr.get(), epi_length, &error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         bidi.set_prologue(prologue_ptr);
         bidi.set_epilogue(epilogue_ptr);
@@ -343,7 +346,7 @@ void init_ubidi(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         ubidi_setLine(para_bidi, start, limit, line_bidi, &error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
       },
       py::arg("para_bidi"), py::arg("start"), py::arg("limit"), py::arg("line_bidi"));
@@ -367,7 +370,7 @@ void init_ubidi(py::module &m) {
         }
         ubidi_setPara(bidi, text_ptr.get(), length, para_level, embedding_levels_ptr.get(), &error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         bidi.set_text(text_ptr);
         bidi.set_embedding_levels(embedding_levels_ptr);
@@ -398,7 +401,7 @@ void init_ubidi(py::module &m) {
         std::u16string result(length, u'\0');
         length = ubidi_writeReordered(bidi, result.data(), (int32_t)result.size(), options, &error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         result.resize(length);
         return result;
@@ -412,7 +415,7 @@ void init_ubidi(py::module &m) {
         const auto length =
             ubidi_writeReverse(src, src_length, result.data(), (int32_t)result.size(), options, &error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         result.resize(length);
         return result;
