@@ -17,7 +17,8 @@ void init_uniset(py::module &m) {
   py::enum_<UMatchDegree>(m, "UMatchDegree", py::arithmetic())
       .value("U_MISMATCH", U_MISMATCH)
       .value("U_PARTIAL_MATCH", U_PARTIAL_MATCH)
-      .value("U_MATCH", U_MATCH);
+      .value("U_MATCH", U_MATCH)
+      .export_values();
 
   // icu::UnicodeFunctor
   py::class_<UnicodeFunctor, UObject>(m, "UnicodeFunctor");
@@ -42,7 +43,7 @@ void init_uniset(py::module &m) {
              UErrorCode error_code = U_ZERO_ERROR;
              auto result = std::make_unique<UnicodeSet>(pattern, error_code);
              if (U_FAILURE(error_code)) {
-               throw ICUException(error_code);
+               throw ICUError(error_code);
              }
              return result;
            }),
@@ -53,7 +54,7 @@ void init_uniset(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = std::make_unique<UnicodeSet>(pattern, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           }),
@@ -63,7 +64,7 @@ void init_uniset(py::module &m) {
              UErrorCode error_code = U_ZERO_ERROR;
              auto result = std::make_unique<UnicodeSet>(pattern, pos, options, symbols.value_or(nullptr), error_code);
              if (U_FAILURE(error_code)) {
-               throw ICUException(error_code);
+               throw ICUError(error_code);
              }
              return result;
            }),
@@ -75,7 +76,7 @@ void init_uniset(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = std::make_unique<UnicodeSet>(pattern, pos, options, symbols.value_or(nullptr), error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           }),
@@ -155,7 +156,7 @@ void init_uniset(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         auto &result = self.applyIntPropertyValue(prop, value, error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return result;
       },
@@ -167,7 +168,7 @@ void init_uniset(py::module &m) {
           UErrorCode error_code = U_ZERO_ERROR;
           auto &result = self.applyPattern(pattern, pos, options, symbols.value_or(nullptr), error_code);
           if (U_FAILURE(error_code)) {
-            throw ICUException(error_code);
+            throw ICUError(error_code);
           }
           return result;
         },
@@ -180,7 +181,7 @@ void init_uniset(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto &result = self.applyPattern(pattern, pos, options, symbols.value_or(nullptr), error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -191,7 +192,7 @@ void init_uniset(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto &result = self.applyPattern(pattern, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -203,7 +204,7 @@ void init_uniset(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto &result = self.applyPattern(pattern, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -214,7 +215,7 @@ void init_uniset(py::module &m) {
           UErrorCode error_code = U_ZERO_ERROR;
           auto &result = self.applyPropertyAlias(prop, value, error_code);
           if (U_FAILURE(error_code)) {
-            throw ICUException(error_code);
+            throw ICUError(error_code);
           }
           return result;
         },
@@ -226,7 +227,7 @@ void init_uniset(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto &result = self.applyPropertyAlias(prop, value, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -238,7 +239,7 @@ void init_uniset(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto &result = self.applyPropertyAlias(prop, value, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -251,7 +252,7 @@ void init_uniset(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto &result = self.applyPropertyAlias(prop, value, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -373,7 +374,7 @@ void init_uniset(py::module &m) {
     error_code = U_ZERO_ERROR;
     self.serialize(result.data(), length, error_code);
     if (U_FAILURE(error_code)) {
-      throw ICUException(error_code);
+      throw ICUError(error_code);
     }
     return result;
   });
